@@ -46,7 +46,7 @@ void add_conf_button_clicked(struct w *widgets)
     select_first_scope(widgets);
 
     /* Populate ranges */
-    set_num_ranges(global_nic, global_subnet, global_netmask);
+    set_num_ranges();
     populate_ranges(widgets, global_nic, global_subnet, global_netmask);
     
     /* Populate the settings */
