@@ -229,7 +229,7 @@ void add_range(struct w *widgets)
     if( range_added )
     {
 	clear_ptr_array(widgets);
-	set_num_ranges(global_nic, global_subnet, global_netmask);
+	set_num_ranges();
 	populate_ranges(widgets, global_nic, global_subnet, global_netmask);
 	populate_scope_settings(widgets);
 
