@@ -305,9 +305,9 @@ void apply_scope_settings(struct w *widgets)
 
 
     /* Change the globals to new nic, subnet and netmask if any */
-    sprintf(global_nic, "%s", change_nic);
-    sprintf(global_subnet, "%s", change_subnet);
-    sprintf(global_netmask, "%s", change_netmask);
+    snprintf(global_nic, 1000, "%s", change_nic);
+    snprintf(global_subnet, 1000, "%s", change_subnet);
+    snprintf(global_netmask, 1000, "%s", change_netmask);
 
     
     /* Insert the saved failover declaration after any global values but
@@ -369,7 +369,7 @@ void apply_scope_settings(struct w *widgets)
 	populate_scope_treeview(widgets);
 	select_first_scope(widgets);
 
-	set_num_ranges(global_nic, global_subnet, global_netmask);
+	set_num_ranges();
 	populate_ranges(widgets, global_nic, global_subnet, global_netmask);
 
 	populate_scope_settings(widgets);
