@@ -27,7 +27,6 @@
 #include "widgets.h"
 #include "make_settings_entries.h"
 #include "make_settings_textviews.h"
-#include "apply_scope_settings.h"
  
 
 
@@ -48,7 +47,7 @@ void create_scope_set_entries(struct w *widgets)
     table2 = gtk_table_new(13, 2, FALSE);
 
     /* Scope settings */
-    gtk_box_pack_start(GTK_BOX(widgets->scope_set_scrolled_vbox), frame1, TRUE, TRUE, 1);
+    gtk_box_pack_start(GTK_BOX(widgets->scope_set_scrolled_vbox), frame1, TRUE, TRUE, 10);
     gtk_container_add(GTK_CONTAINER(frame1), table1);
 							     /* Max length and input 350 chars */
     widgets->scope_set_entry[0] = make_entry_with_label(GTK_TABLE(table1), _(" Network card: "),       0,1,a,b,350);
@@ -64,16 +63,6 @@ void create_scope_set_entries(struct w *widgets)
     a++; b++;
 
 
-    /* Apply button */
-    GtkWidget *scope_set_apply_hbox = gtk_hbox_new(TRUE, FALSE);
-    gtk_box_pack_start(GTK_BOX(widgets->scope_set_scrolled_vbox), scope_set_apply_hbox, TRUE, TRUE, 0);
-
-    GtkWidget *scope_settings_apply_button = gtk_button_new_from_stock(GTK_STOCK_APPLY);
-    gtk_box_pack_start(GTK_BOX(scope_set_apply_hbox), scope_settings_apply_button, FALSE, FALSE, 0);
-    g_signal_connect_swapped(G_OBJECT(scope_settings_apply_button), "clicked", 
-                             G_CALLBACK(apply_scope_settings), widgets);
-
-
     /* Client settings */
     gtk_box_pack_start(GTK_BOX(widgets->scope_set_scrolled_vbox), frame2, TRUE, TRUE, 0);
     gtk_container_add(GTK_CONTAINER(frame2), table2);
