@@ -213,7 +213,7 @@ void delete_range(struct w *widgets)
     if( range_deleted )
     {
 	clear_ptr_array(widgets);
-	set_num_ranges(global_nic, global_subnet, global_netmask);
+	set_num_ranges();
 	populate_ranges(widgets, global_nic, global_subnet, global_netmask);
 	populate_scope_settings(widgets);
 
