@@ -1,5 +1,5 @@
 /* GADMIN-DHCPD - An easy to use GTK+ frontend for ISC DHCPD.
- * Copyright (C) 2004 - 2008 Magnus Loef <magnus-swe@telia.com> 
+ * Copyright (C) 2004 - 2009 Magnus Loef <magnus-swe@telia.com> 
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -20,7 +20,7 @@
 
 
 #ifndef GADMIN_DHCPD_commands_H
-#	define GADMIN_DHCPD_commands_H
+#define GADMIN_DHCPD_commands_H
 
 extern struct w *widgets;
 
@@ -28,6 +28,9 @@ int run_command(gchar *command);
 void run_command_show_err(gchar *command);
 void show_info(char *content);
 int file_exists(char *infile);
+char * get_comments_for_host(char *host_name);
+char * get_comments_for_scope(char *subnet, char *netmask, char *nic);
+int is_selected_host(char *hostname, char *conf_line);
 char * isolate_setting(char *input);
 char * remove_semicolon(char *input);
 void add_missing_values(gchar *conf);
