@@ -89,7 +89,6 @@ int main(int argc, char *argv[])
 
     wid *widgets = g_malloc (sizeof (wid));
 
-
     /* Non root usage */
     if( ! getuid() == 0 )
     {
@@ -117,18 +116,15 @@ int main(int argc, char *argv[])
 	return 0;
     }
 
-
     /* Load saved paths */
     load_settings(widgets);
 
-
     /* Use the defined settings if there are no valid settings */
     if( strlen(DHCPD_CONF_BUF) < 5 )
       snprintf(DHCPD_CONF_BUF, 1000, "%s", DHCPD_CONF);
 
     if( strlen(LEASE_FILE_BUF) < 5 )
       snprintf(LEASE_FILE_BUF, 1000, "%s", LEASE_FILE);
-											 
 
     /* Use command line arguments if we have any */
     if( argc >= 2 )
@@ -182,33 +178,28 @@ int main(int argc, char *argv[])
     widgets->ranges_to_entry_array = g_ptr_array_new();
     widgets->ranges_del_button_array = g_ptr_array_new();
 
+    gtk_widget_show_all(widgets->main_window);
 
     /* Populate the scope treeview */
     populate_scope_treeview(widgets);
     select_first_scope(widgets);
 
     /* Populate scope ranges */
-    set_num_ranges(global_nic, global_subnet, global_netmask);
+    set_num_ranges();
     populate_ranges(widgets, global_nic, global_subnet, global_netmask);
 
     /* Populate the scope settings */
     populate_scope_settings(widgets);
 
-
     /* Populate the host treeview */
     populate_host_treeview(widgets);
     select_first_host(widgets);
 
     populate_host_settings(widgets);
 
-
     /* Populate leases */
     populate_leases(widgets);
 
-
-    gtk_widget_show_all(widgets->main_window);
-
-
     /* Start the online/offline timer */
     gtk_timeout_add(1000, (GtkFunction) status_update, widgets);
 
@@ -237,7 +228,7 @@ int main(int argc, char *argv[])
 
     /* Window (x) close button */
     g_signal_connect(GTK_OBJECT(widgets->main_window), "destroy",
-                         GTK_SIGNAL_FUNC(gtk_main_quit), NULL);
+                    	     GTK_SIGNAL_FUNC(gtk_main_quit), NULL);
 
     /* Start the main loop */
     gtk_main();
