@@ -1,5 +1,5 @@
 /* GADMIN-DHCPD - An easy to use GTK+ frontend for ISC DHCPD.
- * Copyright (C) 2004 - 2008 Magnus Loef <magnus-swe@telia.com> 
+ * Copyright (C) 2004-2009 Magnus Loef <magnus-swe@telia.com> 
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -17,11 +17,10 @@
  *
 */
 
-
 #ifndef HANDLE_SSH
 #define HANDLE_SSH
 
-char ** create_scp_upload_cmd(char *user, char *port, char *file_path, char *dest_path);
+char ** create_scp_upload_cmd(char *user, char *port, char *file, char *user_host_dir);
 
 char ** create_ssh_cmd(char *user, char *host, char *port, char *ssh_cmd);
 
