@@ -42,7 +42,7 @@ void list_scopes(struct w *widgets)
     select_first_scope(widgets);
 
     clear_ptr_array(widgets);
-    set_num_ranges(global_nic, global_subnet, global_netmask);
+    set_num_ranges();
     populate_ranges(widgets, global_nic, global_subnet, global_netmask);
 
     populate_scope_settings(widgets);
