@@ -194,9 +194,7 @@ void apply_loadbalance_button_clicked(struct w *widgets)
 	    "    peer port ", port, ";\n", 
 	    "    max-response-delay ", max_response_delay, ";\n", 
 	    "    max-unacked-updates ", max_unacked_updates, ";\n", 
-//	    "    load balance max seconds ", loadbalance_max_seconds, ";\n", 
 	    "    mclt ", mclt, ";\n",
-//	    "    split ", split, ";\n",
 	    "}\n\n",
 	    NULL);
 	     
@@ -214,10 +212,6 @@ void apply_loadbalance_button_clicked(struct w *widgets)
 	    "    peer port ", remote_port, ";\n", 
 	    "    max-response-delay ", max_response_delay, ";\n", 
 	    "    max-unacked-updates ", max_unacked_updates, ";\n", 
-//	    "    load balance max seconds ", loadbalance_max_seconds, ";\n", 
-//	    "    mclt ", mclt, ";\n",     // Not in a secondary server (Works though)
-//	    "    split ", split, ";\n",   // Not in a secondary server 
-
 	    "}\n\n",
 	    NULL);
 	    
@@ -435,7 +429,7 @@ void apply_loadbalance_button_clicked(struct w *widgets)
 		    strcat(sec_conf, sec_declaration);
 		}
 				    
-		range_from = allocate(file_size+1); // alloc too big
+		range_from = allocate(file_size+1);
 		range_to = allocate(file_size+1);
 		sscanf(line, "%*s %s %s", range_from, range_to);
 
@@ -490,7 +484,7 @@ void apply_loadbalance_button_clicked(struct w *widgets)
 	    /* Continue until theres no more ranges */
 	    if( strstr(line, "range ") )
 	    {
-		range_from = allocate(file_size+1); // alloc too big
+		range_from = allocate(file_size+1);
 		range_to = allocate(file_size+1);
 		sscanf(line, "%*s %s %s", range_from, range_to);
 
@@ -607,7 +601,7 @@ void apply_loadbalance_button_clicked(struct w *widgets)
 	populate_scope_treeview(widgets);
 	select_first_scope(widgets);
 
-	set_num_ranges(global_nic, global_subnet, global_netmask);
+	set_num_ranges();
 	populate_ranges(widgets, global_nic, global_subnet, global_netmask);
 
 	populate_scope_settings(widgets);
@@ -684,9 +678,6 @@ void apply_loadbalance_button_clicked(struct w *widgets)
 	"    peer port ", port, ";\n", 
 	"    max-response-delay ", max_response_delay, ";\n", 
 	"    max-unacked-updates ", max_unacked_updates, ";\n", 
-//	"    load balance max seconds ", loadbalance_max_seconds, ";\n", 
-//	"    mclt ", mclt, ";\n",
-//	"    split ", split, ";\n",
 	"}\n\n",
 	NULL);
     }
@@ -703,9 +694,6 @@ void apply_loadbalance_button_clicked(struct w *widgets)
 	"    max-response-delay ", max_response_delay, ";\n", 
 	"    max-unacked-updates ", max_unacked_updates, ";\n", 
 	"    load balance max seconds ", loadbalance_max_seconds, ";\n", 
-/*	"    mclt ", mclt, ";\n",     // Not in a secondary server (Works though)
-        "    split ", split, ";\n",   // Not in a secondary server 
-*/
         "}\n\n",
         NULL);
 
@@ -817,7 +805,7 @@ void apply_loadbalance_button_clicked(struct w *widgets)
     populate_scope_treeview(widgets);
     select_first_scope(widgets);
 
-    set_num_ranges(global_nic, global_subnet, global_netmask);
+    set_num_ranges();
     populate_ranges(widgets, global_nic, global_subnet, global_netmask);
 
     populate_scope_settings(widgets);
@@ -996,7 +984,7 @@ void delete_loadbalance_button_clicked(struct w *widgets)
 		/* Keep the ranges but fix white spaces */
 		if( strstr(line, "range ") )
 		{
-		    range_from = allocate(file_size+1); // alloc too big
+		    range_from = allocate(file_size+1);
 		    range_to = allocate(file_size+1);
 
 		    sscanf(line, "%*s %s %s", range_from, range_to);
@@ -1061,7 +1049,7 @@ void delete_loadbalance_button_clicked(struct w *widgets)
     populate_scope_treeview(widgets);
     select_first_scope(widgets);
 
-    set_num_ranges(global_nic, global_subnet, global_netmask);
+    set_num_ranges();
     populate_ranges(widgets, global_nic, global_subnet, global_netmask);
 
     populate_scope_settings(widgets);
@@ -1439,7 +1427,6 @@ void show_upload_menu(struct w *widgets)
     gtk_tooltips_set_tip(tooltips, widgets->loadbalance_upload_entry[5], _("The remote dhcp servers restart command"), NULL);
 
 
-
     /* Set remote configuration path as the local one */
     gtk_entry_set_text(GTK_ENTRY(widgets->loadbalance_upload_entry[0]), DHCPD_CONF_BUF);
 
@@ -1447,7 +1434,6 @@ void show_upload_menu(struct w *widgets)
     value = get_failover(nic, subnet, netmask, "peer address");
     gtk_entry_set_text(GTK_ENTRY(widgets->loadbalance_upload_entry[1]), value);
     g_free(value);
-    // FIX: Make it insensitive.
 
     /* Set remote ssh port */
     gtk_entry_set_text(GTK_ENTRY(widgets->loadbalance_upload_entry[2]), "22");
@@ -1461,7 +1447,6 @@ void show_upload_menu(struct w *widgets)
     gtk_entry_set_text(GTK_ENTRY(widgets->loadbalance_upload_entry[5]), "/etc/init.d/dhcp* restart");
 
 
-
     /* The buttons... */
     GtkWidget *settings_hbuttonbox = gtk_hbutton_box_new();
     gtk_box_pack_start(GTK_BOX(settings_vbox), settings_hbuttonbox, FALSE, FALSE, 0);
