@@ -1,5 +1,5 @@
 /* GADMIN-DHCPD - An easy to use GTK+ frontend for ISC DHCPD.
- * Copyright (C) 2004 - 2008 Magnus Loef <magnus-swe@telia.com> 
+ * Copyright (C) 2004 - 2009 Magnus Loef <magnus-swe@telia.com> 
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -32,5 +32,9 @@ void apply_loadbalance_button_clicked(struct w *widgets);
 
 void delete_loadbalance_button_clicked(struct w *widgets);
 
+
+void rewrite_as_secondary_loadbalancer(struct w *widgets);    
+void show_upload_menu(struct w *widgets);
+
 #endif
 
