@@ -28,8 +28,6 @@
 #include "allocate.h"
 #include "functions.h"
 #include "commented.h"
-#include "apply_host_settings.h"
-#include "create_host_set_entries.h"
 
 extern char global_hwaddr[1024];
 extern char global_ipaddr[1024];
@@ -49,36 +47,6 @@ void populate_host_settings(struct w *widgets)
     GtkTooltips *tooltips;
     tooltips = gtk_tooltips_new();
 
-    gtk_widget_destroy(widgets->host_set_scrolled_vbox);
-    widgets->host_set_scrolled_vbox = gtk_vbox_new(FALSE, 0);
-
-    gtk_container_add (GTK_CONTAINER (widgets->host_set_viewport), widgets->host_set_scrolled_vbox);
-
-    /* Host settings label */
-    GtkWidget *host_set_spacer_hbox1 = gtk_hbox_new(FALSE, 0);
-    gtk_box_pack_start(GTK_BOX(widgets->host_set_scrolled_vbox), host_set_spacer_hbox1, FALSE, FALSE, 0);
-    GtkWidget *host_set_spacer_label1 = gtk_label_new("");
-    gtk_box_pack_start(GTK_BOX(host_set_spacer_hbox1), host_set_spacer_label1, TRUE, TRUE, 0);
-
-    /* Apply button */
-    GtkWidget *host_set_apply_hbox = gtk_hbox_new(TRUE, 0);
-    gtk_box_pack_start(GTK_BOX(widgets->host_set_scrolled_vbox), host_set_apply_hbox, TRUE, TRUE, 0);
-
-    GtkWidget *host_set_spacer_label2 = gtk_label_new("");
-    gtk_box_pack_start(GTK_BOX(host_set_apply_hbox), host_set_spacer_label2, FALSE, FALSE, 2);
-
-    GtkWidget *host_settings_apply_button = gtk_button_new_from_stock(GTK_STOCK_APPLY);
-    gtk_box_pack_start(GTK_BOX(host_set_apply_hbox), host_settings_apply_button, FALSE, FALSE, 0);
-    g_signal_connect_swapped(G_OBJECT(host_settings_apply_button), "clicked", 
-                             G_CALLBACK(apply_host_settings), widgets);
-
-    GtkWidget *host_set_spacer_label3 = gtk_label_new("");
-    gtk_box_pack_start(GTK_BOX(host_set_apply_hbox), host_set_spacer_label3, FALSE, FALSE, 5);
-
-
-    /* Create the settings entries and labels in the host table */
-    create_host_set_entries(widgets);
-
 
     /* Populate hostname,ipaddr and hwaddr entries from the global values */
     utf8 = g_locale_to_utf8((char *)global_hostname, strlen(global_hostname), NULL, NULL, NULL);
@@ -383,6 +351,4 @@ void populate_host_settings(struct w *widgets)
 
     if( utf8!=NULL )
       g_free(utf8);
-
-    gtk_widget_show_all(widgets->main_window);
 }
