@@ -42,10 +42,7 @@ void populate_scope_treeview(struct w *widgets)
     gboolean edit=0;
     int set_cursorpath=0;
     long conf_size=0;
-    char *line;
-    char *nic;
-    char *subnet;
-    char *netmask;
+    char *line, *nic, *subnet, *netmask;
     gchar *failover;
 
     gtk_list_store_clear(widgets->scope_store);
@@ -59,7 +56,7 @@ void populate_scope_treeview(struct w *widgets)
     rewind(fp);
 
     line = allocate(conf_size+1);
-    nic = allocate(MAX_CONF_LINE);
+    nic  = allocate(MAX_CONF_LINE);
     subnet = allocate(MAX_CONF_LINE);
     netmask = allocate(MAX_CONF_LINE);
 
@@ -90,6 +87,7 @@ void populate_scope_treeview(struct w *widgets)
 
 		    utf8 = g_locale_to_utf8(netmask, strlen(netmask), NULL, NULL, NULL);
 		    gtk_list_store_set(GTK_LIST_STORE(widgets->scope_store), &iter, 2, utf8, -1);
+
 		    set_cursorpath = 1;
 		    
 		    /* Get the failover peer if any */
@@ -114,8 +112,7 @@ void populate_scope_treeview(struct w *widgets)
 
     if( ! set_cursorpath )
       return;
-    
-    /* FIXME.. Scroll to the correct global nic subnet and netmask (and if its set) set as curpath */
+
     path = gtk_tree_path_new_first();
     gtk_tree_view_set_cursor(GTK_TREE_VIEW(widgets->scope_treeview), path, NULL, edit);
     gtk_tree_path_free(path);
