@@ -64,11 +64,11 @@ void scope_treeview_row_clicked(GtkTreeView *treeview, GdkEventButton *event,
 	    gtk_tree_model_get(list_store, &iter, 1, &subnet, -1);
 	    gtk_tree_model_get(list_store, &iter, 2, &netmask, -1);
 
-	    sprintf(global_subnet, "%s", subnet);
-	    sprintf(global_netmask, "%s", netmask);
-	    sprintf(global_nic, "%s", nic);
+	    snprintf(global_subnet, 1000, "%s", subnet);
+	    snprintf(global_netmask, 1000, "%s", netmask);
+	    snprintf(global_nic, 1000, "%s", nic);
 
-	    set_num_ranges(nic, subnet, netmask);
+	    set_num_ranges();
 	    populate_ranges(data, nic, subnet, netmask);
 	    populate_scope_settings(data);
 
