@@ -54,9 +54,9 @@ void select_first_host(struct w *widgets)
     if( hostname==NULL || ipaddr==NULL || hwaddr==NULL )
       return;
 
-    sprintf(global_hostname, "%s", (gchar *)hostname);
-    sprintf(global_ipaddr, "%s", (gchar *)ipaddr);
-    sprintf(global_hwaddr, "%s", (gchar *)hwaddr);
+    snprintf(global_hostname, 1000, "%s", (gchar *)hostname);
+    snprintf(global_ipaddr, 1000, "%s", (gchar *)ipaddr);
+    snprintf(global_hwaddr, 1000, "%s", (gchar *)hwaddr);
 
     g_free(hostname);
     g_free(ipaddr);
