@@ -57,9 +57,9 @@ void select_first_scope(struct w *widgets)
         return;
     }
 
-    sprintf(global_subnet, "%s", (gchar *)subnet);
-    sprintf(global_netmask, "%s", (gchar *)netmask);
-    sprintf(global_nic, "%s", (gchar *)nic);
+    snprintf(global_subnet, 1000, "%s", (gchar *)subnet);
+    snprintf(global_netmask, 1000, "%s", (gchar *)netmask);
+    snprintf(global_nic, 1000, "%s", (gchar *)nic);
 
     g_free(nic);
     g_free(subnet);
