@@ -36,8 +36,7 @@ extern int num_ranges;
 extern char DHCPD_CONF_BUF[1024];
 
 
-
-void set_num_ranges(gchar *nic, gchar *subnet, gchar *netmask)
+void set_num_ranges()
 {
     FILE *fp;
     long conf_size=0;
@@ -47,15 +46,10 @@ void set_num_ranges(gchar *nic, gchar *subnet, gchar *netmask)
     /* Set some global values */
     num_ranges = 0;
 
-    // FIXME: source and destination overlap
-    sprintf(global_subnet, "%s", subnet);
-    sprintf(global_netmask, "%s", netmask);
-    sprintf(global_nic, "%s", nic);
-    
-    gchar *scope_line1 = g_strdup_printf("subnet %s netmask %s\n", subnet, netmask);
-    gchar *scope_line2 = g_strdup_printf("subnet %s netmask %s{\n", subnet, netmask);
-    gchar *scope_line3 = g_strdup_printf("subnet %s netmask %s {\n", subnet, netmask);
-    gchar *nic_line = g_strdup_printf("interface %s;\n", nic);
+    gchar *scope_line1 = g_strdup_printf("subnet %s netmask %s\n", global_subnet, global_netmask);
+    gchar *scope_line2 = g_strdup_printf("subnet %s netmask %s{\n", global_subnet, global_netmask);
+    gchar *scope_line3 = g_strdup_printf("subnet %s netmask %s {\n", global_subnet, global_netmask);
+    gchar *nic_line = g_strdup_printf("interface %s;\n", global_nic);
 
     if((fp=fopen(DHCPD_CONF_BUF, "r"))==NULL)
     {
@@ -90,7 +84,6 @@ void set_num_ranges(gchar *nic, gchar *subnet, gchar *netmask)
 	  break;
     }
 
-
     if( found_scope && conf_size > 1 )
     {
 	while(fgets(line, conf_size, fp)!=NULL)
