@@ -22,6 +22,6 @@
 #ifndef GADMIN_DHCPD_set_num_ranges_H
 #    define GADMIN_DHCPD_set_num_ranges_H
 
-void set_num_ranges(gchar *nic, gchar *subnet, gchar *netmask);
+void set_num_ranges();
 
 #endif
