@@ -279,7 +279,7 @@ void apply_settings_button_clicked(struct w *widgets)
     populate_scope_treeview(widgets);
     select_first_scope(widgets);
 
-    set_num_ranges(global_nic, global_subnet, global_netmask);
+    set_num_ranges();
     populate_ranges(widgets, global_nic, global_subnet, global_netmask);
 
     populate_scope_settings(widgets);
@@ -373,7 +373,6 @@ void show_settings_window(struct w *widgets)
     widgets->settings_combo[9] = make_combo_with_label(GTK_TABLE(table), _(" Mask-supplier: "),        0,1,a,b,350);
     a++; b++;
 
-
     /* Set entry path texts */
     utf8 = g_locale_to_utf8(DHCPD_CONF_BUF, strlen(DHCPD_CONF_BUF), NULL, NULL, NULL);
     gtk_entry_set_text(GTK_ENTRY(widgets->settings_entry[0]), utf8);
@@ -381,16 +380,122 @@ void show_settings_window(struct w *widgets)
     utf8 = g_locale_to_utf8(LEASE_FILE_BUF, strlen(LEASE_FILE_BUF), NULL, NULL, NULL);
     gtk_entry_set_text(GTK_ENTRY(widgets->settings_entry[1]), utf8);
 
+    GtkWidget *settings_hbuttonbox = gtk_hbutton_box_new();
+    gtk_box_pack_start(GTK_BOX(settings_vbox), settings_hbuttonbox, FALSE, FALSE, 0);
+    gtk_button_box_set_layout(GTK_BUTTON_BOX(settings_hbuttonbox), GTK_BUTTONBOX_SPREAD);
+
+    GtkWidget *apply_settings_button = gtk_button_new_from_stock(GTK_STOCK_APPLY);
+    gtk_container_add(GTK_CONTAINER(settings_hbuttonbox), apply_settings_button);
+    g_signal_connect_swapped(G_OBJECT(apply_settings_button), "clicked", 
+                             G_CALLBACK(apply_settings_button_clicked), widgets);
+    
+    GtkWidget *cancel_settings_button = gtk_button_new_from_stock(GTK_STOCK_CANCEL);
+    gtk_container_add(GTK_CONTAINER(settings_hbuttonbox), cancel_settings_button);
+    g_signal_connect_swapped(G_OBJECT(cancel_settings_button), "clicked", 
+                             G_CALLBACK(cancel_settings_button_clicked), widgets);
+
+    gtk_widget_show_all(widgets->settings_window);
+
+
+    /* Set default combo options */
+    tmp = allocate(1024);
+
+    snprintf(tmp, 1000, "%s", _("Ad-hoc"));
+    utf8 = g_locale_to_utf8(tmp, strlen(tmp), NULL, NULL, NULL);
+    gtk_combo_box_append_text(GTK_COMBO_BOX(widgets->settings_combo[0]), utf8);
+    snprintf(tmp, 1000, "%s", _("Interim"));
+    utf8 = g_locale_to_utf8(tmp, strlen(tmp), NULL, NULL, NULL);
+    gtk_combo_box_append_text(GTK_COMBO_BOX(widgets->settings_combo[0]), utf8);
+    snprintf(tmp, 1000, "%s", _("None"));
+    utf8 = g_locale_to_utf8(tmp, strlen(tmp), NULL, NULL, NULL);
+    gtk_combo_box_append_text(GTK_COMBO_BOX(widgets->settings_combo[0]), utf8);
+
+    snprintf(tmp, 1000, "%s", _("Yes"));
+    utf8 = g_locale_to_utf8(tmp, strlen(tmp), NULL, NULL, NULL);
+    gtk_combo_box_append_text(GTK_COMBO_BOX(widgets->settings_combo[1]), utf8);
+    snprintf(tmp, 1000, "%s", _("No"));
+    utf8 = g_locale_to_utf8(tmp, strlen(tmp), NULL, NULL, NULL);
+    gtk_combo_box_append_text(GTK_COMBO_BOX(widgets->settings_combo[1]), utf8);
+
+    snprintf(tmp, 1000, "%s", _("Allow"));
+    utf8 = g_locale_to_utf8(tmp, strlen(tmp), NULL, NULL, NULL);
+    gtk_combo_box_append_text(GTK_COMBO_BOX(widgets->settings_combo[2]), utf8);
+    snprintf(tmp, 1000, "%s", _("Deny"));
+    utf8 = g_locale_to_utf8(tmp, strlen(tmp), NULL, NULL, NULL);
+    gtk_combo_box_append_text(GTK_COMBO_BOX(widgets->settings_combo[2]), utf8);
+    snprintf(tmp, 1000, "%s", _("Ignore"));
+    utf8 = g_locale_to_utf8(tmp, strlen(tmp), NULL, NULL, NULL);
+    gtk_combo_box_append_text(GTK_COMBO_BOX(widgets->settings_combo[2]), utf8);
+
+    snprintf(tmp, 1000, "%s", _("Yes"));
+    utf8 = g_locale_to_utf8(tmp, strlen(tmp), NULL, NULL, NULL);
+    gtk_combo_box_append_text(GTK_COMBO_BOX(widgets->settings_combo[3]), utf8);
+    snprintf(tmp, 1000, "%s", _("No"));
+    utf8 = g_locale_to_utf8(tmp, strlen(tmp), NULL, NULL, NULL);
+    gtk_combo_box_append_text(GTK_COMBO_BOX(widgets->settings_combo[3]), utf8);
+
+    snprintf(tmp, 1000, "%s", _("Allow"));
+    utf8 = g_locale_to_utf8(tmp, strlen(tmp), NULL, NULL, NULL);
+    gtk_combo_box_append_text(GTK_COMBO_BOX(widgets->settings_combo[4]), utf8);
+    snprintf(tmp, 1000, "%s", _("Deny"));
+    utf8 = g_locale_to_utf8(tmp, strlen(tmp), NULL, NULL, NULL);
+    gtk_combo_box_append_text(GTK_COMBO_BOX(widgets->settings_combo[4]), utf8);
+    snprintf(tmp, 1000, "%s", _("Ignore"));
+    utf8 = g_locale_to_utf8(tmp, strlen(tmp), NULL, NULL, NULL);
+    gtk_combo_box_append_text(GTK_COMBO_BOX(widgets->settings_combo[4]), utf8);
+
+    snprintf(tmp, 1000, "%s", _("Allow"));
+    utf8 = g_locale_to_utf8(tmp, strlen(tmp), NULL, NULL, NULL);
+    gtk_combo_box_append_text(GTK_COMBO_BOX(widgets->settings_combo[5]), utf8);
+    snprintf(tmp, 1000, "%s", _("Deny"));
+    utf8 = g_locale_to_utf8(tmp, strlen(tmp), NULL, NULL, NULL);
+    gtk_combo_box_append_text(GTK_COMBO_BOX(widgets->settings_combo[5]), utf8);
+
+    snprintf(tmp, 1000, "%s", _("Allow"));
+    utf8 = g_locale_to_utf8(tmp, strlen(tmp), NULL, NULL, NULL);
+    gtk_combo_box_append_text(GTK_COMBO_BOX(widgets->settings_combo[6]), utf8);
+    snprintf(tmp, 1000, "%s", _("Deny"));
+    utf8 = g_locale_to_utf8(tmp, strlen(tmp), NULL, NULL, NULL);
+    gtk_combo_box_append_text(GTK_COMBO_BOX(widgets->settings_combo[6]), utf8);
+
+    snprintf(tmp, 1000, "%s", _("Yes"));
+    utf8 = g_locale_to_utf8(tmp, strlen(tmp), NULL, NULL, NULL);
+    gtk_combo_box_append_text(GTK_COMBO_BOX(widgets->settings_combo[7]), utf8);
+    snprintf(tmp, 1000, "%s", _("No"));
+    utf8 = g_locale_to_utf8(tmp, strlen(tmp), NULL, NULL, NULL);
+    gtk_combo_box_append_text(GTK_COMBO_BOX(widgets->settings_combo[7]), utf8);
+
+    snprintf(tmp, 1000, "%s", _("Yes"));
+    utf8 = g_locale_to_utf8(tmp, strlen(tmp), NULL, NULL, NULL);
+    gtk_combo_box_append_text(GTK_COMBO_BOX(widgets->settings_combo[8]), utf8);
+    snprintf(tmp, 1000, "%s", _("No"));
+    utf8 = g_locale_to_utf8(tmp, strlen(tmp), NULL, NULL, NULL);
+    gtk_combo_box_append_text(GTK_COMBO_BOX(widgets->settings_combo[8]), utf8);
+
+    snprintf(tmp, 1000, "%s", _("Yes"));
+    utf8 = g_locale_to_utf8(tmp, strlen(tmp), NULL, NULL, NULL);
+    gtk_combo_box_append_text(GTK_COMBO_BOX(widgets->settings_combo[9]), utf8);
+    snprintf(tmp, 1000, "%s", _("No"));
+    utf8 = g_locale_to_utf8(tmp, strlen(tmp), NULL, NULL, NULL);
+    gtk_combo_box_append_text(GTK_COMBO_BOX(widgets->settings_combo[9]), utf8);
+
+    /* Select the first of every combo option */
+    for(i=0; i<10; i++)
+       gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->settings_combo[i]), 0);
+
+    if( utf8!=NULL )
+      g_free(utf8);
+
+    /* Insert values from dhcpd.conf if any */
     if((fp=fopen(DHCPD_CONF_BUF, "r"))==NULL)
     {
-    
+	free(tmp);    
 	return;
     }
     fseek(fp, 0, SEEK_END);
     file_size = ftell(fp);
     rewind(fp);
     line = allocate(file_size+1);
-    tmp = allocate(file_size+1);
 
     if( file_size > 1 )
     while(fgets(line, file_size, fp)!=NULL)
@@ -403,127 +508,67 @@ void show_settings_window(struct w *widgets)
 
 	if( strstr(line, "ddns-update-style") )
 	{
-	    snprintf(tmp, 1000, "%s", _("Ad-hoc"));
-	    utf8 = g_locale_to_utf8(tmp, strlen(tmp), NULL, NULL, NULL);
-	    gtk_combo_box_append_text(GTK_COMBO_BOX(widgets->settings_combo[0]), utf8);
-
-	    snprintf(tmp, 1000, "%s", _("Interim"));
-	    utf8 = g_locale_to_utf8(tmp, strlen(tmp), NULL, NULL, NULL);
-	    gtk_combo_box_append_text(GTK_COMBO_BOX(widgets->settings_combo[0]), utf8);
-
-	    snprintf(tmp, 1000, "%s", _("None"));
-	    utf8 = g_locale_to_utf8(tmp, strlen(tmp), NULL, NULL, NULL);
-	    gtk_combo_box_append_text(GTK_COMBO_BOX(widgets->settings_combo[0]), utf8);
-
 	    /* Set selected. Cut 18 chars from the beginning of the line */
 	    snprintf(tmp, 1000, "%s", &line[18]);
 	    /* Cut ; and newline */
 	    tmp[strlen(tmp)-2]='\0';
 	    utf8 = g_locale_to_utf8(tmp, strlen(tmp), NULL, NULL, NULL);
-	    if( !strcmp(tmp, "ad-hoc") )
+	    if( strcmp(tmp, "ad-hoc") == 0 )
 	      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->settings_combo[0]), 0);
-	    if( !strcmp(tmp, "interim") )
+	    if( strcmp(tmp, "interim") == 0 )
 	      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->settings_combo[0]), 1);
-	    if( !strcmp(tmp, "none") )
+	    if( strcmp(tmp, "none") == 0 )
 	      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->settings_combo[0]), 2);
 	}
 	else
 	if( strstr(line, "ddns-updates") )
 	{
-	    snprintf(tmp, 1000, "%s", _("Yes"));
-	    utf8 = g_locale_to_utf8(tmp, strlen(tmp), NULL, NULL, NULL);
-	    gtk_combo_box_append_text(GTK_COMBO_BOX(widgets->settings_combo[1]), utf8);
-
-	    snprintf(tmp, 1000, "%s", _("No"));
-	    utf8 = g_locale_to_utf8(tmp, strlen(tmp), NULL, NULL, NULL);
-	    gtk_combo_box_append_text(GTK_COMBO_BOX(widgets->settings_combo[1]), utf8);
-
 	    /* Cut 21 chars from the beginning of the line */
 	    snprintf(tmp, 1000, "%s", &line[13]);
 	    tmp[strlen(tmp)-2]='\0';
-	    if( !strcmp(tmp, "on") )
+	    if( strcmp(tmp, "on") == 0 )
 	      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->settings_combo[1]), 0);
-	    if( !strcmp(tmp, "off") )
+	    if( strcmp(tmp, "off") == 0 )
 	      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->settings_combo[1]), 1);
 	}
 	else
 	if( strstr(line, "client-updates;") )
 	{
-	    snprintf(tmp, 1000, "%s", _("Allow"));
-	    utf8 = g_locale_to_utf8(tmp, strlen(tmp), NULL, NULL, NULL);
-	    gtk_combo_box_append_text(GTK_COMBO_BOX(widgets->settings_combo[2]), utf8);
-
-	    snprintf(tmp, 1000, "%s", _("Deny"));
-	    utf8 = g_locale_to_utf8(tmp, strlen(tmp), NULL, NULL, NULL);
-	    gtk_combo_box_append_text(GTK_COMBO_BOX(widgets->settings_combo[2]), utf8);
-
-	    snprintf(tmp, 1000, "%s", _("Ignore"));
-	    utf8 = g_locale_to_utf8(tmp, strlen(tmp), NULL, NULL, NULL);
-	    gtk_combo_box_append_text(GTK_COMBO_BOX(widgets->settings_combo[2]), utf8);
-
 	    snprintf(tmp, 1000, "%s", line);
 	    tmp[strlen(tmp)-17]='\0';
-	    if( !strcmp(tmp, "allow") )
+	    if( strcmp(tmp, "allow") == 0 )
 	      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->settings_combo[2]), 0);
-	    if( !strcmp(tmp, "deny") )
+	    if( strcmp(tmp, "deny") == 0 )
 	      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->settings_combo[2]), 1);
-	    if( !strcmp(tmp, "ignore") )
+	    if( strcmp(tmp, "ignore") == 0 )
 	      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->settings_combo[2]), 2);
 	}
 	else
 	if( strstr(line, "one-lease-per-client") )
 	{
-	    snprintf(tmp, 1000, "%s", _("Yes"));
-	    utf8 = g_locale_to_utf8(tmp, strlen(tmp), NULL, NULL, NULL);
-	    gtk_combo_box_append_text(GTK_COMBO_BOX(widgets->settings_combo[3]), utf8);
-
-	    snprintf(tmp, 1000, "%s", _("No"));
-	    utf8 = g_locale_to_utf8(tmp, strlen(tmp), NULL, NULL, NULL);
-	    gtk_combo_box_append_text(GTK_COMBO_BOX(widgets->settings_combo[3]), utf8);
-
 	    /* Cut 21 chars from the beginning of the line */
 	    snprintf(tmp, 1000, "%s", &line[21]);
 	    tmp[strlen(tmp)-2]='\0';
-	    if( !strcmp(tmp, "true") )
+	    if( strcmp(tmp, "true") == 0 )
 	      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->settings_combo[3]), 0);
-	    if( !strcmp(tmp, "false") )
+	    if( strcmp(tmp, "false") == 0 )
 	      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->settings_combo[3]), 1);
 	}
         else
 	if( strstr(line, "bootp;") )
 	{
-	    snprintf(tmp, 1000, "%s", _("Allow"));
-	    utf8 = g_locale_to_utf8(tmp, strlen(tmp), NULL, NULL, NULL);
-	    gtk_combo_box_append_text(GTK_COMBO_BOX(widgets->settings_combo[4]), utf8);
-
-	    snprintf(tmp, 1000, "%s", _("Deny"));
-	    utf8 = g_locale_to_utf8(tmp, strlen(tmp), NULL, NULL, NULL);
-	    gtk_combo_box_append_text(GTK_COMBO_BOX(widgets->settings_combo[4]), utf8);
-
-	    snprintf(tmp, 1000, "%s", _("Ignore"));
-	    utf8 = g_locale_to_utf8(tmp, strlen(tmp), NULL, NULL, NULL);
-	    gtk_combo_box_append_text(GTK_COMBO_BOX(widgets->settings_combo[4]), utf8);
-
 	    snprintf(tmp, 1000, "%s", line);
 	    tmp[strlen(tmp)-8]='\0';
-	    if( !strcmp(tmp, "allow") )
+	    if( strcmp(tmp, "allow") == 0 )
 	      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->settings_combo[4]), 0);
-	    if( !strcmp(tmp, "deny") )
+	    if( strcmp(tmp, "deny") == 0 )
 	      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->settings_combo[4]), 1);
-	    if( !strcmp(tmp, "ignore") )
+	    if( strcmp(tmp, "ignore") == 0 )
 	      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->settings_combo[4]), 2);
 	}
         else
 	if( strstr(line, "booting;") )
 	{
-	    snprintf(tmp, 1000, "%s", _("Allow"));
-	    utf8 = g_locale_to_utf8(tmp, strlen(tmp), NULL, NULL, NULL);
-	    gtk_combo_box_append_text(GTK_COMBO_BOX(widgets->settings_combo[5]), utf8);
-
-	    snprintf(tmp, 1000, "%s", _("Deny"));
-	    utf8 = g_locale_to_utf8(tmp, strlen(tmp), NULL, NULL, NULL);
-	    gtk_combo_box_append_text(GTK_COMBO_BOX(widgets->settings_combo[5]), utf8);
-
 	    snprintf(tmp, 1000, "%s", line);
 	    tmp[strlen(tmp)-1]='\0';
 	    if( strstr(tmp, "allow booting;") )
@@ -533,14 +578,6 @@ void show_settings_window(struct w *widgets)
 	}
 	if( strstr(line, "unknown-clients;") )
 	{
-	    snprintf(tmp, 1000, "%s", _("Allow"));
-	    utf8 = g_locale_to_utf8(tmp, strlen(tmp), NULL, NULL, NULL);
-	    gtk_combo_box_append_text(GTK_COMBO_BOX(widgets->settings_combo[6]), utf8);
-
-	    snprintf(tmp, 1000, "%s", _("Deny"));
-	    utf8 = g_locale_to_utf8(tmp, strlen(tmp), NULL, NULL, NULL);
-	    gtk_combo_box_append_text(GTK_COMBO_BOX(widgets->settings_combo[6]), utf8);
-
 	    snprintf(tmp, 1000, "%s", line);
 	    tmp[strlen(tmp)-1]='\0';
 	    if( strstr(tmp, "allow") )
@@ -551,14 +588,6 @@ void show_settings_window(struct w *widgets)
 	else
 	if( strstr(line, "authoritative;") )
 	{
-	    snprintf(tmp, 1000, "%s", _("Yes"));
-	    utf8 = g_locale_to_utf8(tmp, strlen(tmp), NULL, NULL, NULL);
-	    gtk_combo_box_append_text(GTK_COMBO_BOX(widgets->settings_combo[7]), utf8);
-
-	    snprintf(tmp, 1000, "%s", _("No"));
-	    utf8 = g_locale_to_utf8(tmp, strlen(tmp), NULL, NULL, NULL);
-	    gtk_combo_box_append_text(GTK_COMBO_BOX(widgets->settings_combo[7]), utf8);
-
 	    snprintf(tmp, 1000, "%s", line);
 	    tmp[strlen(tmp)-1]='\0';
 	    if( ! strstr(tmp, "not ") )
@@ -569,14 +598,6 @@ void show_settings_window(struct w *widgets)
 	else
 	if( strstr(line, "option ip-forwarding") )
 	{
-	    snprintf(tmp, 1000, "%s", _("Yes"));
-	    utf8 = g_locale_to_utf8(tmp, strlen(tmp), NULL, NULL, NULL);
-	    gtk_combo_box_append_text(GTK_COMBO_BOX(widgets->settings_combo[8]), utf8);
-
-	    snprintf(tmp, 1000, "%s", _("No"));
-	    utf8 = g_locale_to_utf8(tmp, strlen(tmp), NULL, NULL, NULL);
-	    gtk_combo_box_append_text(GTK_COMBO_BOX(widgets->settings_combo[8]), utf8);
-
 	    snprintf(tmp, 1000, "%s", line);
 	    tmp[strlen(tmp)-1]='\0';
 	    if( strstr(tmp, "true") )
@@ -587,14 +608,6 @@ void show_settings_window(struct w *widgets)
 	else
 	if( strstr(line, "option mask-supplier") )
 	{
-	    snprintf(tmp, 1000, "%s", _("Yes"));
-	    utf8 = g_locale_to_utf8(tmp, strlen(tmp), NULL, NULL, NULL);
-	    gtk_combo_box_append_text(GTK_COMBO_BOX(widgets->settings_combo[9]), utf8);
-
-	    snprintf(tmp, 1000, "%s", _("No"));
-	    utf8 = g_locale_to_utf8(tmp, strlen(tmp), NULL, NULL, NULL);
-	    gtk_combo_box_append_text(GTK_COMBO_BOX(widgets->settings_combo[9]), utf8);
-
 	    snprintf(tmp, 1000, "%s", line);
 	    tmp[strlen(tmp)-1]='\0';
 	    if( strstr(tmp, "true") )
@@ -625,20 +638,4 @@ void show_settings_window(struct w *widgets)
 
     if( utf8!=NULL )
       g_free(utf8);
-
-    GtkWidget *settings_hbuttonbox = gtk_hbutton_box_new();
-    gtk_box_pack_start(GTK_BOX(settings_vbox), settings_hbuttonbox, FALSE, FALSE, 0);
-    gtk_button_box_set_layout(GTK_BUTTON_BOX(settings_hbuttonbox), GTK_BUTTONBOX_SPREAD);
-
-    GtkWidget *apply_settings_button = gtk_button_new_from_stock(GTK_STOCK_APPLY);
-    gtk_container_add(GTK_CONTAINER(settings_hbuttonbox), apply_settings_button);
-    g_signal_connect_swapped(G_OBJECT(apply_settings_button), "clicked", 
-                             G_CALLBACK(apply_settings_button_clicked), widgets);
-    
-    GtkWidget *cancel_settings_button = gtk_button_new_from_stock(GTK_STOCK_CANCEL);
-    gtk_container_add(GTK_CONTAINER(settings_hbuttonbox), cancel_settings_button);
-    g_signal_connect_swapped(G_OBJECT(cancel_settings_button), "clicked", 
-                             G_CALLBACK(cancel_settings_button_clicked), widgets);
-
-    gtk_widget_show_all(widgets->settings_window);
 }
